@@ -1,6 +1,6 @@
 ;;; (www server-utils answer) --- HTTP connection handling and responses
 
-;; Copyright (C) 2008, 2009, 2010 Thien-Thi Nguyen
+;; Copyright (C) 2008, 2009, 2010, 2011 Thien-Thi Nguyen
 ;; Copyright (C) 2004, 2006, 2007 Free Software Foundation, Inc.
 ;;
 ;; This file is part of Guile-WWW.
@@ -25,14 +25,25 @@
                  string<-headers
                  string<-header-components
                  mouthpiece)
+  #:use-module (ice-9 curried-definitions)
   #:use-module (ice-9 optargs)
   #:use-module ((ice-9 rw) #:select (write-string/partial)))
 
 (define-macro (+! v n)
   `(set! ,v (+ ,v ,n)))
 
+;; The string ``\r\n''.
+;;
+;;-category: constant string
+;;
 (define CRLF "\r\n")
 
+;; Return the flat length of @var{object},
+;; or @code{#f} if not yet computed.
+;;
+;;-category: object property
+;;-args: (1 0 0 object)
+;;
 (define flat-length (make-object-property))
 
 ;; Return a new string made by using format string @var{s} on @var{args}.
@@ -59,9 +70,10 @@
   (cond ((string? tree) (string-length tree))
         ((null? tree) 0)
         ((flat-length tree))
-        (else (set! (flat-length tree)
-                    (+ (tree-flat-length! (car tree))
-                       (tree-flat-length! (cdr tree)))))))
+        (else (let ((len (+ (tree-flat-length! (car tree))
+                            (tree-flat-length! (cdr tree)))))
+                (set! (flat-length tree) len)
+                len))))
 
 ;; Return a new string made from flattening @var{tree}.
 ;; Set the @code{flat-length} (using @code{tree-flat-length!})
@@ -125,8 +137,6 @@
 ;; Each name may be a string, symbol or keyword.  Each value may be a
 ;; string, number, symbol, or a tree.
 ;;
-;;-sig: (alist [style])
-;;
 (define* (string<-headers alist #:optional (style #f))
   (string<-tree (map (tree<-header-proc (or style http-ish))
                      (map car alist)
@@ -243,8 +253,6 @@
 ;; subsequently.
 ;; @end table
 ;;
-;;-sig: (out-port [status-box [style]])
-;;
 (define* (mouthpiece out-port #:optional (status-box '()) (style #f))
 
   (and (or (not status-box)
