@@ -1,6 +1,6 @@
 ;;; (www server-utils big-dishing-loop) --- Customizable listener and dispatch
 
-;; Copyright (C) 2008, 2009, 2010 Thien-Thi Nguyen
+;; Copyright (C) 2008, 2009, 2010, 2011 Thien-Thi Nguyen
 ;; Copyright (C) 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
 ;;
 ;; This file is part of Guile-WWW.
@@ -36,7 +36,6 @@
   #:use-module (www server-utils answer))
 
 ;; Return a new socket in protocol @var{family} with address @var{name}.
-;; Keywords are: @code{#:socket-setup}.
 ;;
 ;; First, evaluate @code{(socket @var{family} SOCK_STREAM 0)} to create
 ;; a new socket @var{sock}.  Next, handle @code{#:socket-setup}, with
@@ -70,8 +69,6 @@
 ;; Note that @code{PF_foo}, @code{AF_foo}, and @code{INADDR_foo} are
 ;; names of variables that have constant values, not symbols.
 ;;
-;;-sig: (family name [[keyword value] ...])
-;;
 (define* (named-socket family name #:key
                        (socket-setup #f))
   (let ((new (socket family SOCK_STREAM 0)))
@@ -111,7 +108,8 @@
 
 (define http-hgrok (vector read-first-line
                            read-headers
-                           skip-headers))
+                           skip-headers
+                           #f))
 
 ;; Return a proc @var{dish} that loops serving http requests from a socket.
 ;; @var{dish} takes one arg @var{ear}, which may be a pre-configured socket,
@@ -130,7 +128,7 @@
 ;; in order of the steps involved in processing a request, with default values
 ;; shown next to the keyword.
 ;;
-;; @table @code
+;; @table @t
 ;; @findex socket-setup
 ;; @item #:socket-setup #f
 ;; This may be a proc that takes a socket, or a list of opt/val pairs which
@@ -185,6 +183,7 @@
 ;;
 ;; @findex need-headers
 ;; @item #:need-headers #f
+;; @findex need-input-port
 ;; @itemx #:need-input-port #f
 ;; If non-@code{#f}, these cause additional arguments to be supplied to the
 ;; handler proc.  If present, the headers arg precedes the input
@@ -245,8 +244,6 @@
 ;; The default specifies a normal HTTP message (@pxref{http}).
 ;; @end table
 ;;
-;;-sig: ([keyword value ...])
-;;
 (define* (make-big-dishing-loop
           #:key
           (socket-setup #f)
@@ -284,7 +281,7 @@
              ;; status box
              (b (and (number? status-box-size)
                      (make-list status-box-size #f)))
-             (M (mouthpiece p b))
+             (M (mouthpiece p b (vector-ref style 3)))
              (res (cond ((assq-ref method-handlers method)
                          => (lambda (mh)
                               (call-with-current-continuation
